/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.implement;

import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import nl.cloudfarming.client.fleet.machine.windows.MachineOverviewPanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.util.swing.FormRow;
import org.jdesktop.beansbinding.AutoBinding;
import org.jdesktop.beansbinding.BeanProperty;
import org.jdesktop.beansbinding.BindingGroup;
import org.jdesktop.beansbinding.Bindings;
import org.openide.util.NbBundle;

/**
 * Overview Panel for an implement
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"ImplementOverviewPanel workwidth lable text=Work width:"})
public class ImplementOverviewPanel extends MachineOverviewPanel {
    
    private BindingGroup implementBindingGroup = new BindingGroup();
    private BeanProperty fieldPropWorkWidth = BeanProperty.create(Implement.PROP_WORKWIDTH);
    private BeanProperty formPropWorkWidth = BeanProperty.create("value");
    private static final double WORKWIDTH_STEP_SIZE=  0.1;
    private static final double WORKWIDTH_MIN_VALUE = 0.0;
    
    private JSpinner workWidthSpinner;
    
    private Implement implement;
    
    public ImplementOverviewPanel(Implement implement){
        this.implement = implement;
        initComponents();
        bind();
    }
    
    private void initComponents(){
        workWidthSpinner = new JSpinner(new SpinnerNumberModel(WORKWIDTH_MIN_VALUE, WORKWIDTH_MIN_VALUE, Double.MAX_VALUE, WORKWIDTH_STEP_SIZE));
        
        FormRow workWidthRow = new FormRow(false, Bundle.ImplementOverviewPanel_workwidth_lable_text(), Bundle.ImplementOverviewPanel_workwidth_lable_text(), workWidthSpinner);
        add(workWidthRow);
    }
    
    private void bind(){
        implementBindingGroup.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE, implement, fieldPropWorkWidth, workWidthSpinner, formPropWorkWidth));
        implementBindingGroup.bind();
    }

    public JSpinner getWorkWidthSpinner() {
        return workWidthSpinner;
    }
}
