/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.implement.wizard;

import java.util.Calendar;
import java.util.LinkedList;
import java.util.List;
import nl.cloudfarming.client.fleet.implement.ImplementDataService;
import nl.cloudfarming.client.fleet.implement.ImplementManagerImpl;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardOverviewPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardStartPanel;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.WizardDescriptor.Panel;

/**
 *
 * @author Wytse Visser
 */
class ImplementWizardFactory extends MachineWizardFactory {

    public ImplementWizardFactory(Project project) {
        super(project);
    }

    @Override
    public MachineWizardPanel createOverviewPanel() {
        return new MachineWizardOverviewPanel();
    }

    @Override
    public List<Panel<WizardDescriptor>> createInitialPanels() {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new LinkedList<>();
        EnterpriseIdProvider eip = getProject().getLookup().lookup(EnterpriseIdProvider.class);
        Implement implement = new Implement(eip, "");
        final int currentYear = Calendar.getInstance().get(Calendar.YEAR);
        implement.setYear(currentYear);
        panels.add(new MachineWizardStartPanel(this, implement));
        return panels;
    }

    @Override
    public Class<? extends MachineDataService> getDataServiceClass() {
        return ImplementDataService.class;
    }

    @Override
    public Class<? extends MachineProvider> getMachineProviderClass() {
        return ImplementManagerImpl.class;
    }

}
